@@ -3,21 +3,10 @@ use nstd_core::slice::NSTDSlice;
 use nstd_gui::{NSTDWindow, NSTDWindowSize};
 use std::{
     ffi::CString,
-    os::raw::{c_char, c_double, c_int},
+    os::raw::{c_char, c_int},
     ptr,
 };
-use wgpu::{
-    util::{BufferInitDescriptor, DeviceExt},
-    Adapter, Backend, Backends, BlendState, Buffer, BufferAddress, BufferUsages, Color,
-    ColorTargetState, ColorWrites, CommandEncoderDescriptor, Device, DeviceDescriptor, DeviceType,
-    Face, FragmentState, FrontFace, IndexFormat, Instance, LoadOp, MultisampleState, Operations,
-    PipelineLayoutDescriptor, PolygonMode, PowerPreference, PresentMode, PrimitiveState,
-    PrimitiveTopology, Queue, RenderPass, RenderPassColorAttachment, RenderPassDescriptor,
-    RenderPipeline, RenderPipelineDescriptor, RequestAdapterOptions, ShaderModule,
-    ShaderModuleDescriptor, ShaderSource, Surface, SurfaceConfiguration, TextureUsages,
-    TextureViewDescriptor, VertexAttribute, VertexBufferLayout, VertexFormat, VertexState,
-    VertexStepMode,
-};
+use wgpu::{util::*, *};
 #[cfg(feature = "deps")]
 pub mod deps {
     pub use futures;
@@ -27,14 +16,8 @@ pub mod deps {
 }
 
 /// Represents a color.
-#[repr(C)]
-#[derive(Default)]
-pub struct NSTDGLColor {
-    pub r: c_double,
-    pub g: c_double,
-    pub b: c_double,
-    pub a: c_double,
-}
+// Must match https://docs.rs/wgpu/0.12.0/wgpu/struct.Color.html.
+pub type NSTDGLColor = Color;
 
 /// Represents a graphical surface.
 pub type NSTDGLSurface = *mut Surface;
@@ -379,7 +362,7 @@ impl<'a> Into<VertexBufferLayout<'a>> for NSTDGLVertexBufferLayout {
 ///     `const NSTDGLStateDescriptor descriptor` - Configures the state.
 /// Returns: `NSTDGLState state` - The new GL state.
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_gl_state_new(
+pub unsafe extern "C" fn nstd_gl_state_new(
     window: NSTDWindow,
     descriptor: NSTDGLStateDescriptor,
 ) -> NSTDGLState {
@@ -398,7 +381,7 @@ pub unsafe extern "C" fn nstd_std_gl_state_new(
             Ok((device, queue)) => (device, queue),
             _ => return NSTDGLState::default(),
         };
-    let size = nstd_gui::nstd_std_gui_window_get_client_size(window);
+    let size = nstd_gui::nstd_gui_window_get_client_size(window);
     let config = SurfaceConfiguration {
         usage: TextureUsages::RENDER_ATTACHMENT,
         format: match surface.get_preferred_format(&adapter) {
@@ -427,7 +410,7 @@ pub unsafe extern "C" fn nstd_std_gl_state_new(
 ///     `void(*callback)(NSTDGLRenderPass)` - Manipulates the render pass.
 /// Returns: `int errc` - Nonzero on error.
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_gl_state_render(
+pub unsafe extern "C" fn nstd_gl_state_render(
     state: &NSTDGLState,
     callback: extern "C" fn(NSTDGLRenderPass),
 ) -> c_int {
@@ -447,12 +430,7 @@ pub unsafe extern "C" fn nstd_std_gl_state_render(
                 view: &view,
                 resolve_target: None,
                 ops: Operations {
-                    load: LoadOp::Clear(Color {
-                        r: state.clear_color.r,
-                        g: state.clear_color.g,
-                        b: state.clear_color.b,
-                        a: state.clear_color.a,
-                    }),
+                    load: LoadOp::Clear(state.clear_color),
                     store: true,
                 },
             }],
@@ -470,10 +448,7 @@ pub unsafe extern "C" fn nstd_std_gl_state_render(
 ///     `NSTDGLState *const state` - The GL state.
 ///     `const NSTDWindowSize *const new_size` - The new context size.
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_gl_state_resize(
-    state: &mut NSTDGLState,
-    new_size: &NSTDWindowSize,
-) {
+pub unsafe extern "C" fn nstd_gl_state_resize(state: &mut NSTDGLState, new_size: &NSTDWindowSize) {
     if new_size.width > 0 && new_size.height > 0 {
         state.size = *new_size;
         (*state.config).width = new_size.width;
@@ -486,7 +461,7 @@ pub unsafe extern "C" fn nstd_std_gl_state_resize(
 /// Parameters:
 ///     `NSTDGLState *const state` - The GL state.
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_gl_state_free(state: &mut NSTDGLState) {
+pub unsafe extern "C" fn nstd_gl_state_free(state: &mut NSTDGLState) {
     Box::from_raw(state.surface);
     Box::from_raw(state.config);
     Box::from_raw(state.device_handle);
@@ -504,7 +479,7 @@ pub unsafe extern "C" fn nstd_std_gl_state_free(state: &mut NSTDGLState) {
 ///     `NSTDGLDeviceHandle device_handle` - Handle to a device.
 /// Returns: `NSTDGLDeviceInfo device_info` - Contains information about a device.
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_gl_device_handle_get_info(
+pub unsafe extern "C" fn nstd_gl_device_handle_get_info(
     device_handle: NSTDGLDeviceHandle,
 ) -> NSTDGLDeviceInfo {
     let info = (*device_handle).get_info();
@@ -527,7 +502,7 @@ pub unsafe extern "C" fn nstd_std_gl_device_handle_get_info(
 ///     `NSTDGLDevice device` - The device to create the shader module on.
 /// Returns: `NSTDGLShaderModule shader` - The new shader module.
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_gl_shader_module_new(
+pub unsafe extern "C" fn nstd_gl_shader_module_new(
     data: &NSTDSlice,
     device: NSTDGLDevice,
 ) -> NSTDGLShaderModule {
@@ -545,7 +520,7 @@ pub unsafe extern "C" fn nstd_std_gl_shader_module_new(
 ///     `NSTDGLShaderModule *shader` - Pointer to a shader module.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_gl_shader_module_free(shader: &mut NSTDGLShaderModule) {
+pub unsafe extern "C" fn nstd_gl_shader_module_free(shader: &mut NSTDGLShaderModule) {
     Box::from_raw(*shader);
     *shader = ptr::null_mut();
 }
@@ -559,7 +534,7 @@ pub unsafe extern "C" fn nstd_std_gl_shader_module_free(shader: &mut NSTDGLShade
 ///     `NSTDGLSurfaceConfiguration config` - The surface configuration.
 /// Returns: `NSTDGLRenderPipeline pipeline` - The new render pipeline.
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_gl_render_pipeline_new(
+pub unsafe extern "C" fn nstd_gl_render_pipeline_new(
     vert: NSTDGLShaderModule,
     frag: NSTDGLShaderModule,
     buffers: &NSTDSlice,
@@ -630,7 +605,7 @@ pub unsafe extern "C" fn nstd_std_gl_render_pipeline_new(
 ///     `NSTDGLRenderPipeline *pipeline` - Pointer to a render pipeline.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_gl_render_pipeline_free(pipeline: &mut NSTDGLRenderPipeline) {
+pub unsafe extern "C" fn nstd_gl_render_pipeline_free(pipeline: &mut NSTDGLRenderPipeline) {
     Box::from_raw(*pipeline);
     *pipeline = ptr::null_mut();
 }
@@ -641,7 +616,7 @@ pub unsafe extern "C" fn nstd_std_gl_render_pipeline_free(pipeline: &mut NSTDGLR
 ///     `NSTDGLRenderPipeline pipeline` - The render pipeline.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_gl_render_pass_set_pipeline(
+pub unsafe extern "C" fn nstd_gl_render_pass_set_pipeline(
     render_pass: NSTDGLRenderPass,
     pipeline: NSTDGLRenderPipeline,
 ) {
@@ -655,7 +630,7 @@ pub unsafe extern "C" fn nstd_std_gl_render_pass_set_pipeline(
 ///     `const NSTDUInt32 slot` - The buffer slot (the index of the buffer layout).
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_gl_render_pass_set_vertex_buffer(
+pub unsafe extern "C" fn nstd_gl_render_pass_set_vertex_buffer(
     render_pass: NSTDGLRenderPass,
     buffer: NSTDGLBuffer,
     slot: u32,
@@ -670,7 +645,7 @@ pub unsafe extern "C" fn nstd_std_gl_render_pass_set_vertex_buffer(
 ///     `NSTDGLIndexFormat format` - The index format of the buffer.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_gl_render_pass_set_index_buffer(
+pub unsafe extern "C" fn nstd_gl_render_pass_set_index_buffer(
     render_pass: NSTDGLRenderPass,
     buffer: NSTDGLBuffer,
     format: NSTDGLIndexFormat,
@@ -685,7 +660,7 @@ pub unsafe extern "C" fn nstd_std_gl_render_pass_set_index_buffer(
 ///     `const NSTDUInt32 instances` - Number of instnaces.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_gl_render_pass_draw(
+pub unsafe extern "C" fn nstd_gl_render_pass_draw(
     render_pass: NSTDGLRenderPass,
     verticies: u32,
     instances: u32,
@@ -701,7 +676,7 @@ pub unsafe extern "C" fn nstd_std_gl_render_pass_draw(
 ///     `const NSTDInt32 base` - The base vertex.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_gl_render_pass_draw_indexed(
+pub unsafe extern "C" fn nstd_gl_render_pass_draw_indexed(
     render_pass: NSTDGLRenderPass,
     indicies: u32,
     instances: u32,
@@ -715,7 +690,7 @@ pub unsafe extern "C" fn nstd_std_gl_render_pass_draw_indexed(
 ///     `NSTDGLDeviceInfo *const device_info` - Pointer to an `NSTDGLDeviceInfo` object.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_gl_device_info_free(device_info: &mut NSTDGLDeviceInfo) {
+pub unsafe extern "C" fn nstd_gl_device_info_free(device_info: &mut NSTDGLDeviceInfo) {
     drop(CString::from_raw(device_info.name));
     device_info.name = ptr::null_mut();
 }
@@ -727,7 +702,7 @@ pub unsafe extern "C" fn nstd_std_gl_device_info_free(device_info: &mut NSTDGLDe
 /// Returns: `NSTDGLBuffer buffer` - The new GPU buffer.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_gl_buffer_new(
+pub unsafe extern "C" fn nstd_gl_buffer_new(
     bytes: &NSTDSlice,
     device: NSTDGLDevice,
 ) -> NSTDGLBuffer {
@@ -745,7 +720,7 @@ pub unsafe extern "C" fn nstd_std_gl_buffer_new(
 ///     `NSTDGLBuffer *const buffer` - The GPU buffer.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_gl_buffer_free(buffer: &mut NSTDGLBuffer) {
+pub unsafe extern "C" fn nstd_gl_buffer_free(buffer: &mut NSTDGLBuffer) {
     Box::from_raw(*buffer);
     *buffer = ptr::null_mut();
 }
